/**
 * @description transform rax base to react base. For Now only work for nuke
 * @stage 1 transform react-dom
 * @stage 1.1 use react-dom's render
 * @stage 1.2 add render paramater for dom.getElementById
 * @stage 2 transfrom prop-dom
 * @stage 3 transform style by wrap function
 */
const babel = require('babel-core');
const t = require('babel-types');
const template = require('babel-template');

let raxRenderExist = false; // 是否调用了rax的render方法
let isRaxFile = false; // 是否引用了rax
let hasFindDOM = false;

const ADJUST_REACT_REM_FUNCTION = 'adjustReactRem';

const setNativePolyfill = `
    function setNativeProps(ref,object) {
        var element = new Option;
        if(object && object.style){
            Object.keys(object.style).forEach(function (a) { element.style[a] = object.style[a]; })
            findDOMNode(ref).style = element.getAttribute('style');
        }
    }
`;

// 代码量较大，最好能够shakeing掉
const adjustReactRemPolyfill = `
function ${ADJUST_REACT_REM_FUNCTION}(style) {
    // @todo transform 是否需要处理
    var attribute = [
        'fontSize',
        'width', 'height', 'minWidth', 'minHeight', 'maxWidth', 'maxHeight',
        'margin', 'padding',
        'marginLeft', 'marginRight', 'marginTop', 'marginBottom', 'paddingLeft', 'paddingRight', 'paddingTop', 'paddingBottom', 'borderWidth',
        'borderLeftWidth', 'borderRightWidth', 'borderBottomWidth', 'borderRadius', 'borderBottomLeftRadius', 'borderBottomRightRadius', 'borderTopLeftRadius', 'borderTopRightRadius',
        'top', 'bottom', 'left', 'right'
    ]
    var dp = 750 / 100;
    var stylesheetObj = {};
    // @warning Array.isArray是否需要增加polyfill
    if (Array.isArray(style)) {
        // @warning Object.assign 兼容性待确定，或添加polyfill
        for (var i = 0; i < style.length; i++) {
            Object.assign(stylesheetObj, style[i]);
        }
    } else {
        stylesheetObj = style;
    }
    for (var key in stylesheetObj) {
        if (attribute.indexOf(key) > -1) {
            if(key === 'fontSize'){
                console.log('------->',stylesheetObj[key],'=====>',dp)
            };
            if (/^\\d+$/.test(stylesheetObj[key])) {
                stylesheetObj[key] = (stylesheetObj[key] / dp).toFixed(6) + 'vw';
            } else if (typeof stylesheetObj[key] === 'string' && stylesheetObj[key].indexOf('rem') > -1) {
                stylesheetObj[key] = (stylesheetObj[key].replace('rem', '') / dp).toFixed(6) + 'vw';
            }
        }
    }
    return stylesheetObj;
}
`;

const insertFindDOMNode = function (path) {
  path.parentPath.insertAfter(
    t.importDeclaration(
      [t.importSpecifier(t.identifier('findDOMNode'), t.identifier('findDOMNode'))],
      t.stringLiteral('react-dom')
    )
  );
};

const visitor = {
  ImportDeclaration(path) {
    if (path.node.source && path.node.source.value === 'rax') {
      path.node.source.value = 'react';
      path.insertAfter(template(adjustReactRemPolyfill)());
      isRaxFile = true;
      return;
    }
  },
  ImportSpecifier(path) {
    if (isRaxFile && path.node.imported.name === 'PropTypes') {
      if (path.parent.source.value === 'react') {
        path.remove();
        path.parentPath.insertAfter(
          t.importDeclaration([t.importDefaultSpecifier(t.identifier('PropTypes'))], t.stringLiteral('prop-types'))
        );
      }
    } else if (path.node.imported.name === 'render') {
      if (path.parent.source.value === 'react') {
        raxRenderExist = true;
        path.remove();
        path.parentPath.insertAfter(
          t.importDeclaration(
            [t.importSpecifier(t.identifier('render'), t.identifier('render'))],
            t.stringLiteral('react-dom')
          )
        );
      }
    } else if (path.node.imported.name === 'setNativeProps') {
      if (path.parent.source.value === 'react') {
        path.parentPath.insertAfter(template(setNativePolyfill)());
        path.remove();
        if (hasFindDOM) {
          return;
        }
        // 插入
        insertFindDOMNode(path);
      }
    } else if (path.node.imported.name === 'findDOMNode') {
      if (path.parent.source.value === 'react') {
        path.remove();
        insertFindDOMNode(path);
        if (hasFindDOM) {
          return;
        }
        hasFindDOM = true;
      }
    }
    return;
  },

  CallExpression(path) {
    // filter render not from react-dom
    if (path.node.callee.name !== 'render' || !raxRenderExist) return;
    // console.log(path.getStatementParent());
    if (path.node.arguments.length === 1) {
      const args = path.node.arguments;
      args.push(template('document.getElementsByTagName("body")[0]')().expression);
      path.replaceWith(t.callExpression(path.node.callee, args));
    }
  },
  // need  jsx transform plugin before this plugin
  JSXAttribute(path) {
    if (isRaxFile && path.node.name && path.node.name.name === 'style') {
      if (
        path.node.value.expression &&
        path.node.value.expression.callee &&
        path.node.value.expression.callee.name === ADJUST_REACT_REM_FUNCTION
      ) {
        return;
      }
      const args = [path.node.value.expression];
      const expression = t.callExpression(t.identifier(ADJUST_REACT_REM_FUNCTION), args);
      path.replaceWith(t.jSXAttribute(t.jSXIdentifier('style'), t.jSXExpressionContainer(expression)));
    }
  },
};

const code = `
import { Component,setNativeProps } from 'rax';
class TextDemo extends Component {
    constructor() {
      super();
    }
    ComponentDidMount(){
        setNativeProps(this.refs.view,{backgroundColor:'#333333'});
    }
    render() {
      return (
        <View ref="view">
          <Text style={{ fontSize: 14, marginLeft: 20 }}>测试</Text>
          <Text style={customFunc(aaaa)}>测试</Text>
        </View>
      );
    }
  }
`;
// const result = babel.transform(code, {
//   presets: [require('babel-preset-rax')],
//   plugins: [
//     {
//       visitor,
//     },
//   ],
// });
// console.log(result.code);
module.exports = function () {
  return {
    visitor,
    post() {
      // after file transform clear the variable
      raxRenderExist = false;
      isRaxFile = false;
      hasFindDOM = false;
    },
  };
};
