'use strict';

import { padding } from 'nuke-core';

function valueToObj(obj) {
  Object.keys(obj).map((name) => {
    if (typeof obj[name] === 'object') {
      obj[name] = {
        name,
        raw: obj[name],
      };
    }
  });
  return obj;
}

function buttonColor(
  color,
  activeColor,
  bgColor,
  activeBgColor,
  borderColor,
  activeBorderColor,
  opacity
) {
  return valueToObj(
    Object.assign(
      {
        color,
        backgroundColor: bgColor,
        borderColor,
        'color:active': activeColor,
        'backgroundColor:active': activeBgColor,
        'borderColor:active': activeBorderColor,
      },
      opacity ? { opacity } : {}
    )
  );
}

function buttonSize(
  pd = 0,
  height = 0,
  fontSize = 0,
  iconSize = 0,
  iconMargin = 0,
  corner = 0,
  borderWidth = 0
) {
  return valueToObj({
    height,
    ...padding(0, pd),
    fontSize,
    borderRadius: corner,
    borderWidth,
  });
}

function buttonDisabled(
  disabledColor,
  disabledBgColor,
  disabledBorderColor,
  disbledOpacity
) {
  return valueToObj({
    color: disabledColor,
    backgroundColor: disabledBgColor,
    borderColor: disabledBorderColor,
    opacity: disbledOpacity,
    'color:active': disabledColor,
    'backgroundColor:active': disabledBgColor,
    'borderColor:active': disabledBorderColor,
  });
}

function hexToRgb(hex, opacity) {
  // Expand shorthand form (e.g. "03F") to full form (e.g. "0033FF")
  const shorthandRegex = /^#?([a-f\d])([a-f\d])([a-f\d])$/i;
  hex = hex.replace(shorthandRegex, (m, r, g, b) => r + r + g + g + b + b);

  const result = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(hex);
  if (!result) return null;

  return {
    r: parseInt(result[1], 16),
    g: parseInt(result[2], 16),
    b: parseInt(result[3], 16),
  };
}
// function rgba(hex, opacity) {
//   if ('raw' in hex) {
//     hex = hex.raw;
//   }
//   if ('raw' in opacity) {
//     opacity = opacity.raw;
//   }

//   const result = hexToRgb(hex);
//   if (!result) return null;

//   return `rgba(${result.r},${result.g},${result.b},${opacity})`;
// }

module.exports = {
  buttonColor,
  buttonSize,
  buttonDisabled,
  // rgba,
};
