/** @jsx createElement */

/**
 * Copyright (c) 2015-present, Alibaba Group Holding Limited.
 * All rights reserved.
 *
 */
'use strict';
/**
 * 一个实例中相同的iconfont资源只需被调用一次，如果对iconfont有二次封装会导致调用次数过多在客户端出现闪动
 * 单例模式  相同的url算一个单例
 */
const isWeex = typeof callNative === 'function';

const ICON_CACHE_KEY = '_nuke_icon_cache_';

class Iconfont {
  init(options) {
    const { url, name } = options;

    if (!url || !name) return;
    let urlFit = url;
    if (isWeex) {
      if (url.indexOf('//at.alicdn.com') === 0) {
        urlFit = 'https:' + urlFit;
      }
      var domModule = require('@weex-module/dom');
      domModule.addRule('fontFace', {
        fontFamily: name,
        src: "url('" + urlFit + "')"
      });
    } else {
      if (isDefined(name, urlFit)) return;
      var css =
          "@font-face {font-family: '" +
          name +
          "';src: url('" +
          urlFit +
          "');}",
        head = document.head || document.getElementsByTagName('head')[0],
        style = document.createElement('style');

      style.type = 'text/css';
      if (style.styleSheet) {
        style.styleSheet.cssText = css;
      } else {
        style.appendChild(document.createTextNode(css));
      }

      head.appendChild(style);
      cacheDefineResult(name, urlFit);
    }
  }
}
/**
 * check if this font family has been defined
 * @param {*} name iconfontName
 * @param {*} url iconfontURL
 */
function isDefined(name, url) {
  if (isWeex) return false;
  let CacheArray =
    window[ICON_CACHE_KEY] && window[ICON_CACHE_KEY][name]
      ? window[ICON_CACHE_KEY][name]
      : null;
  if (!CacheArray) return false;

  if (
    'name' in CacheArray &&
    'url' in CacheArray &&
    CacheArray.name === name &&
    CacheArray.url === url
  ) {
    return true;
  }
  return false;
}
/**
 *
 * @param {*} name
 * @param {*} url
 */
function cacheDefineResult(name, url) {
  if (isWeex) return;
  window[ICON_CACHE_KEY] = window[ICON_CACHE_KEY] || {};
  window[ICON_CACHE_KEY][name] = { name, url };
}
/**
 * @param {string/obj} unicode &#xe615;e6DD;\e6dd;
 */
function formatUnicode(unicode) {
  if (typeof unicode !== 'string' && process.env.NODE_ENV === 'development') {
    cosnole.warn('formatUnicode only support <string> arguments');
  }
  let tmpUnicode = unicode.raw || unicode;
  if (tmpUnicode.indexOf('&#x') === 0) {
    tmpUnicode = String.fromCodePoint(
      parseInt(tmpUnicode.replace('&#x', '0x').replace(';', ''), 16)
    );
  } else if (tmpUnicode.indexOf('\\u') === 0) {
    tmpUnicode = unicode;
  } else {
    tmpUnicode = String.fromCodePoint(
      parseInt(
        `0x${tmpUnicode
          .replace(/(e[\w\d]{3})/, '$1')
          .replace(/\\/, '')
          .replace(';', '')}`,
        16
      )
    );
  }
  return tmpUnicode;
}
function Output(params) {
  new Iconfont().init(params);
}
Output.isDefined = isDefined;
Output.cacheDefineResult = cacheDefineResult;
Output.formatUnicode = formatUnicode;
export default Output;
