/** @jsx createElement */
'use strict';

import { createElement, Component, PropTypes } from 'weex-rx';
import { TouchableHighlight, View, Text, Image } from 'nuke-components';
import Radio from './radio.js';
import radioStyles from '../styles.js';
const RADIO_TYPES = {
  group: 'radio-group',
  horizontal: 'RadioHorizontal',
  'small-text': 'radio-group-small-text',
  'medium-text': 'radio-group-medium-text'
};
class RadioGroup extends Component {
  constructor(props) {
    super(props);
    this.onChange = this.onChange.bind(this);
    this.displayName = 'RadioGroup';
    let value;
    if ('value' in props) {
      value = props.value;
    }
    this.state = {
      selectedValue: value
    };
  }
  componentWillReceiveProps(nextProps, nextContext) {
    if (nextProps.value != this.state.selectedValue) {
      this.setState({
        selectedValue: nextProps.value
      });
    }
  }
  getChildContext() {
    return {
      __group__: true,
      onChange: this.onChange,
      selectedValue: this.state.selectedValue
    };
  }

  onChange(value, e) {
    //同一个group下只能有一个被选中
    //
    this.setState({
      selectedValue: value
    });
    this.props.onChange(value);
  }

  render() {
    let { children } = this.props;
    const {
      onChange,
      dataSource = [],
      style = {},
      size,
      horizontal
    } = this.props;
    let groupStyle = radioStyles[RADIO_TYPES['group']];
    let wrapStle;
    if (horizontal) {
      wrapStle = radioStyles[RADIO_TYPES['horizontal']];
    }
    const textStyle =
      size && size == 'small'
        ? radioStyles[RADIO_TYPES['small-text']]
        : radioStyles[RADIO_TYPES['medium-text']];
    const current = this.state.selectedValue;

    if (!children) {
      children = dataSource.map((item, index) => {
        if (typeof item !== 'object') {
          item = { label: item, value: item };
        }
        const { label, value, ...others } = item;
        let checked = false;
        current == value ? (checked = true) : (checked = false);

        if (label) {
          return (
            <View t="radio-item-wrap" key={index} style={groupStyle}>
              <Radio
                t="radioitem"
                {...others}
                size={size}
                value={value}
                checked={checked}
              />
              <Text t="radiotext" style={textStyle}>
                {label}
              </Text>
            </View>
          );
        } else {
          return (
            <View t="radio-item-wrap" style={groupStyle}>
              <Radio {...others} checked={checked} />
            </View>
          );
        }
      });
    }

    return (
      <View t="radio-group-wrap" style={wrapStle}>
        {children}
      </View>
    );
  }
}
RadioGroup.propTypes = {
  dataSource: PropTypes.array,
  onChange: PropTypes.func,
  value: PropTypes.any
};

RadioGroup.defaultProps = {
  dataSource: [],
  onChange: () => {},
  value: ''
};
RadioGroup.childContextTypes = {
  onChange: PropTypes.func,
  __group__: PropTypes.bool,
  selectedValue: PropTypes.any
};
export default RadioGroup;
