/** @jsx createElement */
'use strict';

import { createElement, Component, PropTypes } from 'weex-rx';
import { TouchableHighlight, View, Text, Image } from 'nuke-components';
import Icon from 'nuke-icon';
import { isWeex, isWeb } from 'nuke-env';

import radioStyles from '../styles.js';
const SHOW = isWeex ? 'show' : 'block';
const HIDE = isWeex ? 'hide' : 'none';
const RADIO_TYPES = {
  radio: 'radio',
  wrap: 'radio-wrap',
  small: 'radio-small',
  medium: 'radio-medium',
  disabled: 'radio-disabled',
  checked: 'radio-checked',
  touch: 'radio-touch'
};

class Radio extends Component {
  constructor(props, context) {
    super(props);
    this.displayName = 'Radio';
    this.onChange = this.onChange.bind(this);
    let checked = props.checked || false;

    this.state = {
      checked: checked,
      value: props.value || ''
    };
  }
  componentWillMount() {
    if (
      this.context.__group__ &&
      this.context.selectedValue == this.props.value
    ) {
      this.state = {
        checked: true
      };
    }
  }
  onChange(e) {
    const { onChange, value, disabled } = this.props;

    if (disabled) return;
    if (this.context.__group__) {
      this.context.onChange(value, e);
    } else {
      this.setState({
        checked: true
      });
    }
    onChange(true);
  }

  componentWillReceiveProps(nextProps, nextContext) {
    if (nextContext.__group__) {
      if (
        typeof nextContext == 'object' &&
        nextContext.selectedValue == nextProps.value
      ) {
        this.setState({ checked: true });
      } else {
        this.setState({ checked: false });
      }
    } else {
      if ('checked' in nextProps) {
        if (nextProps.checked != this.props.checked)
          this.setState({
            checked: nextProps.checked
          });
      }
    }
  }
  render() {
    const { size, style, disabled, type } = this.props;
    let { checked, value } = this.state;
    // this.context.selectedValue == value ? checked=true : "";

    const sizeStyle = RADIO_TYPES[size];
    const radioStyle = RADIO_TYPES['checked'];
    const disabledStyle = RADIO_TYPES['disabled'];
    let imgCSS = radioStyles[sizeStyle];

    const unradioStyle = Object.assign(
      { backgroundColor: '#ffffff' },
      radioStyles[sizeStyle],
      radioStyles[`${RADIO_TYPES['wrap']}-${type}-${size}`]
    );

    let wrapCSS = checked
      ? Object.assign({}, unradioStyle, radioStyles[radioStyle])
      : Object.assign({}, unradioStyle);
    wrapCSS = disabled
      ? Object.assign({}, radioStyles[disabledStyle], wrapCSS)
      : wrapCSS;
    let touchCSS = Object.assign(
      {},
      radioStyles[`${RADIO_TYPES['touch']}-${size}`],
      style
    );

    return (
      <TouchableHighlight style={touchCSS} onPress={this.onChange}>
        <View style={wrapCSS}>
          {checked ? <Icon style={imgCSS} name="select" /> : null}
        </View>
      </TouchableHighlight>
    );
  }
}

Radio.propTypes = {
  checked: PropTypes.boolean,
  size: PropTypes.oneOf(['small', 'medium']),
  disabled: PropTypes.boolean,
  onChange: PropTypes.func,
  type: PropTypes.oneOf(['normal', 'list', 'dark']),
  value: PropTypes.string
};

Radio.defaultProps = {
  size: 'medium',
  disabled: false,
  checked: false,
  onChange: () => {},
  type: 'normal',
  value: ''
};
Radio.contextTypes = {
  onChange: PropTypes.func,
  __group__: PropTypes.bool,
  selectedValue: PropTypes.any
};
export default Radio;
