'use strict';

import qs from 'qs';
import Uri from './uri';

export default {
  urlParse: function(url) {
    // add qap:// & qap:/// support
    var reg = /(qap:\/{2,3})/g;
    url = url.replace(reg, 'qap:///');

    var obj = {};
    var uri = new Uri(url);

    obj.protocol = uri.protocol() + ':';
    obj.hostname = uri.host();
    obj.port = uri.port();
    obj.host = obj.hostname + (obj.port ? ':' + obj.port : '');
    obj.origin = obj.protocol + '//' + obj.host;
    obj.pathname = uri.path();
    obj.search = uri.query();
    obj.hash = uri.anchor() ? '#' + uri.anchor() : '';
    return obj;
  },
  getSearchParameter: function(search, paramName) {
    const res = qs.parse(search, {
      ignoreQueryPrefix: true,
      plainObjects: true
    });
    return res[paramName];
  },
  setSearchParameter: function(search, params, options = {}) {
    const defaultOptions = { addQueryPrefix: true, ...options };
    const origin = options.keepOrigin
      ? qs.parse(search, { ignoreQueryPrefix: true, plainObjects: true })
      : {};
    return qs.stringify({ ...origin, ...params }, defaultOptions);
  }
};
