const babel = require('babel-core');
const path = require('path');
const glob = require('glob');
const fse = require('fs-extra');
const apiExtractor = require('@ali/fusion-api-extractor');
const log = require('../utils/log');

const PATTERN_JS = /\.js?$/;
const PATTERN_JSX = /\.jsx$/;

const PATTERN_NUKE_LIB = 'packages/nuke-*/';
/**
 * @description babel pacakges
 * @step1  clear lib directory
 * @step2  get package need babel
 * @step3  use apiExtractor to get api
 * @param {*} cwd  current process path
 * @param {*} args pass by process args
 */
module.exports = async function (cwd, args) {
  process.env.NODE_ENV = 'production';
  if (args && args.length > 0 && args[0] === 'react') {
    process.env.BABEL_ENV = 'production:react';
  }
  const dirs = glob.sync(PATTERN_NUKE_LIB, { cwd });

  log.debug(dirs);

  dirs.map(async (dir) => {
    const absPath = path.join(cwd, dir);
    const libPath = path.join(absPath, 'lib');
    const srcPath = path.join(absPath, 'src');
    // babel file
    if (fse.existsSync(libPath)) {
      await fse.remove(libPath);
    }
    const files = glob.sync('**/*.*', { cwd: srcPath });

    files.map(async (file) => {
      const filePath = path.join(srcPath, file);
      const libFilePath = path.join(libPath, file);

      let content = await fse.readFile(filePath);
      if (PATTERN_JS.test(file)) {
        content = transform(filePath, content);
        file = file.replace(PATTERN_JSX, '.js');
      }
      await fse.outputFile(libFilePath, content);
    });
    // extract api info
    try {
      const apiInfo = apiExtractor.extract(srcPath);
      const apiSchemaPath = path.join(libPath, 'api-schema.json');
      if (apiInfo) {
        const apiString = JSON.stringify(apiInfo, null, 2);
        await fse.outputFile(apiSchemaPath, apiString);
      }
    } catch (err) {
      log.warn(JSON.stringify(err));
      log.wran('generate api-schema.json failed. No side effect');
    }
  });
  log.info('Babel Build Over');
};

function transform(fileName, content) {
  const result = babel.transform(content.toString(), { filename: fileName });

  return new Buffer(result.code);
}
