const path = require('path');
const glob = require('glob');
const fse = require('fs-extra');

global.packages = [];
global.selectPackages = [];
/**
 * @description  get doc file list for filepath
 * @param {*} filepath  **\**.js
 * @param {*} callback
 */
exports.getDocFileList = function (filePath) {
  return glob.sync(path.join(filePath, '/docs/*.{js,jsx,md}'));
};
/**
 * @description get docs entry
 * @param {*} cwd
 * @param {*} filePath
 */
exports.getDocWebpackEntry = function (cwd, selectPackages) {
  const entry = {};
  this.filterSelectPkg(selectPackages).map((pkg) => {
    const docs = this.getDocFileList(pkg.value);
    docs.forEach((file) => {
      const ext = path.extname(file);
      const name = path.basename(file, ext);
      const pathWithoutExt = path.join(path.dirname(file), name).replace(`${pkg.value}/`, `${pkg.name}/`);

      entry[pathWithoutExt] = file.replace(/\\/g, '/');
    });
  });
  return entry;
};
/**
 * @description get name & value for package
 * @param {*} selectPackages
 * @param {*} packages
 */
exports.filterSelectPkg = function (selectPackages) {
  const selectPkgValue = [];
  global.packages.map((pkg) => {
    if (selectPackages.indexOf(pkg.name) > -1) {
      selectPkgValue.push(pkg);
    }
  });
  return selectPkgValue;
};
/**
 * @description only return debug packages alias
 * @param {*} cwd
 * @param {*} packages
 */
exports.getDocAlias = function (cwd, selectPackages) {
  const alias = {};
  this.filterSelectPkg(selectPackages).map((pkg) => {
    alias[pkg.name] = path.join(pkg.value, 'src/index');
  });
  return alias;
};

/**
 * @description get packages from dir packages
 * @param {*} cwd
 */
exports.getPackages = function (cwd) {
  const pkgs = glob.sync(path.join(cwd, 'packages/*'));
  global.packages = pkgs.map(pkg => ({
    name: fse.readJsonSync(path.join(pkg, 'package.json')).name,
    value: pkg,
  }));
  return global.packages;
};

exports.deleteUpxDepsFiles = async function (absRootPath, com) {
  await fse.remove(path.join(absRootPath, 'deps.json'));
  await fse.remove(path.join(absRootPath, 'build'));
  await fse.remove(path.join(absRootPath, '.cachefile'));
};
