/**
 * Created by hugo on 16/5/10.
 */

const fs = require('fs');
const path = require('path');
const gitlab = require('node-gitlab');
const spawn = require('cross-spawn');
const semver = require('semver');

const cwd = process.cwd();
const request = require('request');

const config = {
  api: 'http://gitlab.alibaba-inc.com/api/v3',
  // fie_admin的token
  privateToken: 'E8JD26cJrdQ93MiZGQFv',
};
const client = gitlab.createPromise(config);

module.exports = {
  /**
   * 同步package.json的版本号为当前分支的版本
   */
  syncPackageVersion() {
    const file = path.join(cwd, 'package.json');

    let pkg;

    let branch;

    if (fs.existsSync(file)) {
      pkg = require(file);
      branch = this.getCurBranch();
      branch = branch.replace('daily/', '');
      // 判断一下 是否是标准的 x.y.z格式
      if (semver.valid(branch)) {
        pkg.version = branch;
        fs.writeFileSync(file, JSON.stringify(pkg, null, 2), { encoding: 'utf8' });
        return branch;
      }
    }
  },
  /**
   * 获取当前分支
   * @returns {string}
   */
  getCurBranch() {
    const headerFile = path.join(cwd, '.git/HEAD');
    const gitVersion = (fs.existsSync(headerFile) && fs.readFileSync(headerFile, { encoding: 'utf8' })) || '';
    const arr = gitVersion.split(/refs[\\\/]heads[\\\/]/g);
    const v = (arr && arr[1]) || '';
    return v.trim();
  },
  /**
   * 判断本地是否有当前daily分支
   * @method function
   * @return {[type]} [description]
   */

  isBranchExist(version) {
    const headerFile = path.join(cwd, `.git/refs/heads/daily/${version}`);
    console.log(headerFile);
    const gitVersion = fs.existsSync(headerFile); // && fs.readFileSync(headerFile, {encoding: 'utf8'}) || '';
    return gitVersion;
  },

  /**
   * 获取package中的desction字段
   * @returns {string|*}
   */
  getDescription() {
    const file = path.join(cwd, 'package.json');

    let pkg;

    let description = '';

    if (fs.existsSync(file)) {
      pkg = require(file);
      description = pkg.description;
    }
    return description;
  },

  /**
   * 获取project name 和 group name
   * @returns {*}
   */
  getProjectAndGroupName() {
    const file = path.join(cwd, '.git/config');
    const pkgFile = path.join(cwd, 'package.json');
    let pg;
    let gitConfig;
    let match;

    if (fs.existsSync(file)) {
      gitConfig = fs.readFileSync(file, { encoding: 'utf8' });
      if (!/git@gitlab.alibaba-inc.com:(.*)/.test(gitConfig)) {
        gitConfig = '';
      }
    }

    if (!gitConfig && fs.existsSync(pkgFile)) {
      gitConfig = require(pkgFile).repository;
      if (gitConfig && typeof gitConfig !== 'string') {
        gitConfig = gitConfig.url;
      }
    }

    if (gitConfig) {
      match = gitConfig.match(/git@gitlab.alibaba-inc.com:(.*)/);
      if (match && match[1]) {
        pg = match[1].split('/');
        return {
          groupName: pg[0],
          projectName: pg[1].replace('.git', ''),
        };
      }
    }

    return {};
  },

  /**
   * 获取用户信息
   */
  getUserInfo() {
    const results = spawn.sync('git', ['config', '--list']);
    const data = {
      author: '',
      email: '',
    };
    try {
      // 分成2个正则
      const regUser = /user\.name=([^\n]+)\n/;
      const regEmail = /user\.email=([^\n]+)\n/;
      const matchUser = results.stdout.toString().match(regUser);
      const matchEmail = results.stdout.toString().match(regEmail);
      // console.log(match,'==match')
      if (matchUser) {
        data.author = matchUser[1];
      }
      if (matchEmail) {
        data.email = matchEmail[1];
      }
    } catch (e) {
      console.log(e);
    }

    return data;
  },

  /**
   * 根据namepace 获取 id
   */
  getNamespaceIdByName(name) {
    // namespaces
    return new Promise((resolve, reject) => {
      request(
        {
          url: `${config.api}/namespaces?per_page=100&private_token=${config.privateToken}`, // http://gitlab.alibaba-inc.com/api/v3/namespaces?private_token=4k3Yx3xVx3xkhUENyQtC',
          timeout: 5000,
          json: true,
        },
        (error, response, body) => {
          let id;
          if (body && body.length) {
            body.forEach((item) => {
              if (item.path === name) {
                id = item.id;
              }
            });

            resolve(id);
          } else {
            reject(Error('error'));
          }
        }
      );
    });
  },
  /**
   * 获取该项目下所有 有权限的用户
   */
  listUsers() {
    const that = this;
    const gitInfo = that.getProjectAndGroupName();
    return new Promise((resolve, reject) => {
      Promise.all([that.getProject(), that.getNamespaceIdByName(gitInfo.groupName)]).then((data) => {
        client.projectMembers
          .list({
            id: data[0].id,
          })
          .then(pUser => pUser, () => [])
          .then((pUser) => {
            client.groupMembers
              .list({
                id: data[1],
              })
              .then(
                (gUser) => {
                  const users = gUser.concat(pUser);
                  resolve(users);
                },
                () => {
                  resolve(pUser);
                }
              )
              .catch((err) => {
                reject(err);
              });
          });
      });
    });
  },

  /**
   * 获取user信息
   */
  getUser() {
    const that = this;
    return new Promise((resolve, reject) => {
      const userInfo = that.getUserInfo();
      if (userInfo && userInfo.email) {
        // client
        client.users
          .list({
            search: userInfo.email,
          })
          .then((data) => {
            if (data && data.length) {
              data[0].email = userInfo.email;
              resolve(data[0]);
            } else {
              // gitlab上没有找到该用户
              reject(new Error('no'));
            }
          });
      } else {
        // 当前机器上没有安装git
        reject(new Error('git'));
      }
    });
  },

  addUserToProject() {
    const that = this;
    // console.log(123)
    return new Promise((resolve, reject) => {
      // 获取user 和 project 信息 再添加用户到project
      Promise.all([that.getUser(), that.getProject()]).then((data) => {
        if (data && data[0] && data[1]) {
          client.projectMembers
            .create({
              user_id: data[0].id,
              id: data[1].id,
              access_level: 40,
            })
            .then((response) => {
              if (response && response.id) {
                resolve(data);
              } else {
                reject(Error('create'));
              }
            });
        } else {
          reject(Error('create'));
        }
      });
    });
  },
};
