const path = require('path');
const fse = require('fs-extra');
const Basement = require('@alipay/basement');
const upxClient = require('@ali/upx-client').upxClient('production');
const shell = require('shelljs');
const inquirer = require('inquirer');
const git = require('./git');
const log = require('./log');

const cwd = process.cwd();

const ZIP_BUILD_FILE_NAME = 'dist.tar.gz';

exports.publish = async function (entryDir) {
  const urllib = require('urllib').create({
    agent: false,
    httpsAgent: false,
  });
  const pkgJSON = require(path.join(entryDir, 'package.json'));
  const tarOptions = {
    env: 'daily',
    pkgName: pkgJSON.name,
    version: pkgJSON.version,
    tarDir: 'build',
    tarFileName: ZIP_BUILD_FILE_NAME,
    tarExcludePatterns: [],
    timeTagFn: () => parseInt(Date.now() / (10 * 60 * 1000)),
    depsJSONPattern: '.cachefile/deps.*.json',
    depsDestPath: 'build/deps.json',
  };
  const ShellCMD = `cd ${entryDir}/build/; tar ${tarOptions.tarExcludePatterns
    .map(pattern => `--exclude ${pattern}`)
    .join(' ')} -zcvf ${tarOptions.tarFileName} ./* ; cd ${cwd};`;
  shell.exec(ShellCMD, {
    silent: true,
  });
  const zipPath = path.join(entryDir, tarOptions.tarDir, tarOptions.tarFileName);

  // 文件上传
  const basement = new Basement({
    appId: '594231ec6a90ae4c1cacf29d',
    masterKey: '9PBa_cdHCt7UiDIhFVGCkZDI',
    urllib,
    // endpoint: 'http://basement.stable.alipay.net', // stable 环境
    // endpoint: 'https://basement-api.alipay.com', // prod 环境
    endpoint: 'https://basement-gzone.alipay.com', // prod 环境，但是直接指向 gzone 集群，对于线下应用访问线上 basement 服务来说会更快速
    file: {
      timeout: '30s', // 文件上传超时时间，默认 30s
    },
  });

  const TIME_TAG = tarOptions.timeTagFn();
  const res = await basement.file.upload(
    `${tarOptions.pkgName}/${tarOptions.env}/${tarOptions.version}/${TIME_TAG}/${path.basename(zipPath)}`,
    zipPath,
    {
      mode: 'internal',
      keepPath: true,
      force: true,
    }
  );
  fse.removeSync(zipPath);
  log.info(`[1/2]Upload to OSS URL:${res.url}`);

  const curUserName = git.getUserInfo().author;

  const upxParams = [
    {
      name: tarOptions.pkgName,
      version: tarOptions.version,
      buildAssetsPath: res.url,
      type: 1, // envTypes.indexOf(tarOptions.env),
      creator: curUserName,
    },
  ];
  const sync = await inquirer.prompt([
    {
      name: 'sync',
      type: 'confirm',
      default: true,
      message: log.warn('是否同步到upx，同步后无法修改，可能会直接被线上应用使用'),
    },
  ]);
  if (sync.sync) {
    const uploadRes = await upxClient.request('npmService.pushBuildFileToCDN', upxParams);
    console.log(uploadRes);
    log.info('[2/2]Sync UPX success!');
  }
};
