/**
 * @description 分端打包脚本，根据基本的webpack入参，返回webpack数组，对代码进行rax web/weex/raect的分端处理
 */
const cloneDeep = require('lodash.clonedeep');
const _ = require('lodash');
const RaxWebpackPlugin = require('rax-webpack-plugin');

const babelConfig = require('../../babel.config');

const platformLoader = require.resolve('./platformLoader');

module.exports = function (config, options) {
  const platforWhiteList = ['web', 'node', 'weex', 'react'];

  const pkgInfo = options.pkgJson;
  let raxPluginParam = {
    externalBuiltinModules: true,
    target: 'bundle',
    bundle: 'compatible',
    moduleName: pkgInfo.name,
    builtinModules: {},
  };

  let platforms = options.platforms;
  platforms = platforms.filter((platform) => {
    const p = platform.toLowerCase();
    if (platforWhiteList.indexOf(p) !== -1) {
      return true;
    }
    return false;
  });

  if (platforms === 0) {
    const errInfo = 'platform does not support !';
    throw new Error(errInfo);
  }

  const mutipleConfigs = [];
  const entry = config.entry;

  if (typeof entry === 'object') {
    const entries = Object.keys(entry);

    platforms.forEach((platform) => {
      const platformType = platform.toLowerCase();
      const platformConfig = cloneDeep(config);
      const platformEntry = {};
      let nameQuery = '';
      if (Array.isArray(options.name)) {
        options.name.map((name) => {
          nameQuery += `&name[]=${name}`;
        });
      }
      // index => index.react.js & index.node.js ...
      entries.forEach((name) => {
        platformEntry[`${name}.${platformType}`] = entry[name];
      });
      platformConfig.entry = platformEntry;
      platformConfig.name = platformType;

      // 针对不同环境的打包处理
      platformConfig.module.rules.push({
        test: /\.jsx?$/,
        exclude: /(node_modules|bower_components)/,
        loader: `${platformLoader}?platform=${platformType}${nameQuery}`,
      });

      platformConfig.module.rules.forEach((rule) => {
        if (rule.loader === 'babel-loader') {
          if (platformType === 'react') {
            rule.options = babelConfig['production:react'];
          } else {
            rule.options = babelConfig.production;
          }
        }
      });

      platformConfig.externals.push((context, request, callback) => {
        if (request.indexOf('node_modules') === -1) {
          if (platformType === 'weex') {
            if (request.indexOf('./web') > -1) {
              return callback(null, `amd ${request}`);
            }
          } else if (platformType === 'web' || platformType === 'react') {
            if (request.indexOf('./native') > -1) {
              return callback(null, `amd ${request}`);
            }
          }
        }
        callback();
      });

      raxPluginParam = _.merge(raxPluginParam, {
        sourcePrefix(source, chunk, hash) {
          const externals = chunk.mapModules().filter(m => m.constructor.name === 'ExternalModule');
          let externalsDepsArray = externals
            .filter((m) => {
              if (platformType === 'weex') {
                if (m.request.indexOf('./web') > -1) {
                  return false;
                }
                return true;
              } else if (platformType === 'web' || platformType === 'react') {
                if (m.request.indexOf('./native') > -1) {
                  return false;
                }
                return true;
              }
              return true;
            })
            .map(m => m.request);
          externalsDepsArray = JSON.stringify(externalsDepsArray);
          return `define("${
            pkgInfo.name
          }", ${externalsDepsArray}, function(require, exports, module) { module.exports = `;
        },
        sourceSuffix(source, chunk, hash) {
          return '});';
        },
      });

      platformConfig.plugins.unshift(new RaxWebpackPlugin(raxPluginParam));

      mutipleConfigs.push(platformConfig);
    });
    mutipleConfigs.unshift(config);
  }
  return mutipleConfigs;
};
