/**
 * 给每个package打包，发布upx
 */
const webpack = require('webpack');
const log = require('../../utils/log');

const upxConfig = require('./upx.config');
/**
 * upx的发布需要按照依赖次序依次发布，并确保发布成功.
 */
module.exports = async function (entryDir) {
  const webpackConfig = await upxConfig(entryDir);
  const compiler = webpack(webpackConfig);

  await new Promise((resolve, reject) => {
    compiler.run((err, stats) => {
      if (err) {
        log.err('UPX build failed:\n');
        log.err(JSON.stringify(err));
        process.exit(-1);
        reject(err);
      }
      if (stats.hasErrors()) {
        log.err(stats);
        process.exit(-1);
        reject(stats);
      }
      console.log(
        stats.toString({
          chunks: false,
          color: true,
        })
      );
      resolve();
    });
  });
};
