/**
 * 构建deps.json cmd包,需要按照依赖一个一个包处理
 * @todo  该服务不对外网开放
 */
const path = require('path');
const getDepMap = require('@ali/deps-json-webpack-plugin');
const UglifyJsPlugin = require('uglifyjs-webpack-plugin');
const MinifyPlugin = require('babel-minify-webpack-plugin');
const MultiplePlatform = require('../mutiplePlatform');
const utils = require('./utils');
const getPlugins = require('./plugins');
const baseConfig = require('../webpack.config');

const cwd = process.cwd();
// 兼容process.utils.info
process.utils = utils;

module.exports = async function (entryDir) {
  const pkgJson = require(path.join(entryDir, 'package.json'));

  const depConfig = {
    dependencies: pkgJson.dependencies,
    modBasePath: 'npm',
    comBasePath: 'npm',
    version: pkgJson.version,
    modName: pkgJson.name,
    suffix: '.cmd',
    entrySuffix: '.cmd',
    disableBuiltIn: true,
    disableXtplReplace: true,
    depsJsonDest: 'build',
    type: 'origin',
  };
  baseConfig.mode = 'production';
  baseConfig.output.filename = '[name].cmd.js';
  baseConfig.output.publicPath = '/build/';
  baseConfig.output.path = path.join(entryDir, 'build');

  baseConfig.entry = {
    index: `${entryDir}/src/index`,
  };
  const result = await getDepMap(depConfig);
  const verJSON = result.verJSON;
  const ExternalDep = [];
  for (const dep in verJSON) {
    if (verJSON[dep]) {
      ExternalDep.push(dep);
    }
  }

  const ExternalReg = new RegExp(`^${ExternalDep.join('|')}$`);
  const defaultExternal = {
    rax: 'commonjs rax',
    react: 'React',
    'react-dom': 'ReactDOM',
    process: 'process',
  };

  baseConfig.externals = [
    function (context, request, callback) {
      if (ExternalReg.test(request)) {
        let modName = request.replace('@ali/', 'npm/@ali');
        const info = modName.split('/');
        if (info.length === 3) {
          modName += '/index';
        }
        return callback(null, modName, 'commonjs');
      }
      if (defaultExternal[request]) {
        return callback(null, defaultExternal[request]);
      }
      callback();
    },
  ];
  baseConfig.optimization = { minimize: true };
  baseConfig.plugins = getPlugins({
    options: {
      entryDir,
    },
    pkgJson,
  });
  //   baseConfig.plugins.push(new MinifyPlugin());
  const resultConfig = MultiplePlatform(baseConfig, {
    platforms: ['web', 'weex', 'react'],
    pkgJson,
    name: ['nuke-env', 'universal-env', '@ali/universal-env'],
    chunkFilename(platformType) {
      return `[name].${platformType}.js`;
    },
  });
  return resultConfig;
};
