/**
 * fork from http://gitlab.alibaba-inc.com/builder/builder-mod/blob/master/lib/utils.js
 * compat with deps.json lib
 */

'use strict';

const chalk = require('chalk');
/**
 * 输出标准日志格式到终端
 *
 * Colors
 *   black
 *   red
 *   green
 *   yellow
 *   blue (on Windows the bright version is used as normal blue is illegible)
 *   magenta
 *   cyan
 *   white
 *   gray
 *
 * Background colors
 *   bgBlack
 *   bgRed
 *   bgGreen
 *   bgYellow
 *   bgBlue
 *   bgMagenta
 *   bgCyan
 *   bgWhite
 *
 * @param prefix
 * @param color
 * @param {Array | String} message
 */
function output(prefix, color, message) {
  let args = [`${chalk[color || 'green'](prefix || 'info')}`, `${chalk.magenta('[kit:light:builder]')}`];

  if (message instanceof Array) {
    args = args.concat(message);
  } else {
    args.append(message);
  }

  console.log(...args);
}

function info() {
  output('info', 'green', Array.prototype.slice.call(arguments, 0));
}

function warn() {
  output('warn', 'yellow', Array.prototype.slice.call(arguments, 0));
}

function error() {
  output('ERR!', 'red', Array.prototype.slice.call(arguments, 0));
}

function verbose() {
  output('verb', 'blue', Array.prototype.slice.call(arguments, 0));
}

module.exports = {
  log: {
    info,
    warn,
    error,
    verbose,
  },
};
