const path = require('path');
const webpack = require('webpack');
const RaxPlugin = require('rax-webpack-plugin');

const cwd = process.cwd();

const isDEV = process.env.NODE_ENV === 'development';
const TemplatePath = path.join(cwd, 'scripts/template');

module.exports = {
  mode: isDEV ? 'development' : 'production',
  target: 'web',
  node: false,
  output: {
    publicPath: '/',
    filename: '[name].js',
  },
  resolve: {
    extensions: ['.js', '.jsx', '.json'],
  },
  externals: [autoExternal()],
  module: {
    rules: [
      {
        test: /\.(jsx|js)$/,
        exclude: /node_modules\/!(nuke-[\w-\d]*)/,
        loader: 'babel-loader',
      },
      {
        test: /\.md/,
        exclude: /node_modules\/!(nuke-[\w-\d]*)/,
        use: [
          { loader: 'babel-loader' },
          { loader: `atool-doc-md-loader?template=${path.join(TemplatePath, 'docs.ejs')}` },
        ],
      },
    ],
  },
  plugins: [
    new webpack.ProgressPlugin((percentage, msg) => {
      const stream = process.stderr;
      if (stream.isTTY && percentage < 0.71) {
        stream.cursorTo(0);
        stream.write(`📦   ${msg}`);
        stream.clearLine(1);
      } else if (percentage === 1) {
        console.log('\nwebpack: bundle build is now finished.');
      }
    }),
  ],
};

const defaultExternal = {
  rax: 'commonjs rax',
};
function autoExternal() {
  return function (context, request, callback) {
    // 排除掉@weex-module
    if (/^@weex-module\//.test(request)) {
      return callback(null, 'commonjs ' + request); // eslint-disable-line
    }
    if (defaultExternal[request]) {
      return callback(null, defaultExternal[request]);
    }
    callback();
  };
}
